@@ -1,6 +1,7 @@
 # Module: appTrial.py
 # Holds data structures
 
+
 import sys
 from sys import platform as _platform
 import csv
@@ -12,7 +13,9 @@ import datetime
 import tkinter
 from operator import add
 from collections import defaultdict
-from xlrd import open_workbook
+import pkg_resources
+import pandas as pd
+
 if sys.version_info<(3,0,0):  # tkinter names for python 2
     print("Update to Python3 for best results... You may encounter errors")
     from Tkinter import *
@@ -310,53 +313,47 @@ def saveFileAsExperiment(software, filename, filedirectory):
         if software == "ethovision":
             logging.info("Reading file ethovision")
             experiment.setHasAnimalNames(True)
-            experiment.setHasDateInfo(True)
+            experiment.setHasDateInfo(False)
             experiment.setHasTrialNames(True)
 
             try:
-                wb = open_workbook(filename)
+                sheet = pd.read_excel(filename, header = None)
                 logging.debug("Opened" + filename)
             except Exception:
                 traceback.print_exc()
                 logging.error("Unable to open excel file " + filename)
                 return
 
-            for sheet in wb.sheets():  # for all sheets in the workbook
-                number_of_rows = sheet.nrows
-                headerLines = int(sheet.cell(0, 1).value)  # gets number of header lines in the spreadsheet
-                aTrial = Trial()
+            number_of_rows = len(sheet)
+            headerLines = int(sheet.iloc[0,1])  # gets number of header lines in the spreadsheet
+            aTrial = Trial()
 
-                for row in range(1, headerLines):
-                    if sheet.cell(row, 0).value.upper() == 'TRIAL NAME':
-                        aTrial.setname(sheet.cell(row, 1).value)
-                    elif sheet.cell(row, 0).value.upper() == 'TRIAL ID':
-                        aTrial.settrial(int(sheet.cell(row, 1).value))
-                    elif sheet.cell(row, 0).value.upper() == 'START TIME':
-                        aTrial.setdate(datetime.datetime.strptime(sheet.cell(row, 1).value, "%d/%m/%Y %H:%M:%S"))
-                    elif sheet.cell(row, 0).value.upper() == 'ANIMAL ID':
-                        aTrial.setanimal(sheet.cell(row, 1).value)
-                    elif sheet.cell(row, 0).value.upper() == 'DAY':
-                        aTrial.setday(sheet.cell(row, 1).value)
-                    elif sheet.cell(row, 0).value.upper() == 'TRIAL':
-                        aTrial.settrial(int(sheet.cell(row, 1).value))
+            for row in range(1, headerLines):
+                if str(sheet.iloc[row, 0]).upper() == 'TRIAL NAME':
+                        aTrial.setname(sheet.iloc[row,1])
+                elif str(sheet.iloc[row, 0]).upper() == 'TRIAL ID':
+                    aTrial.settrial(int(sheet.iloc[row,1]))
+                elif str(sheet.iloc[row, 0]).upper() == 'ANIMAL ID':
+                    aTrial.setanimal(sheet.iloc[row,1])
+                elif str(sheet.iloc[row, 0]).upper() == 'TRIAL':
+                    aTrial.settrial(int(sheet.iloc[row,1]))
 
-                for row in range(headerLines, number_of_rows):  # for each row
-                    time = sheet.cell(row, 1).value
-                    x = sheet.cell(row, 2).value
-                    y = sheet.cell(row, 3).value
+            for row in range(headerLines, number_of_rows):  # for each row
+                time = sheet.iloc[row,1]
+                x = sheet.iloc[row,2]
+                y = sheet.iloc[row,3]
 
-                    if time == "NaN" or x == "NaN" or y == "NaN":
-                        aTrial.markDataAsCorrupted()
-                        continue
+                if time == "NaN" or x == "NaN" or y == "NaN":
+                    aTrial.markDataAsCorrupted()
+                    continue
 
-                    try:
-                        aTrial.append(Datapoint(float(time), float(x), float(y)))
-                    except ValueError:
-                        aTrial.markDataAsCorrupted()
-                        pass
+                try:
+                    aTrial.append(Datapoint(float(time), float(x), float(y)))
+                except ValueError:
+                    aTrial.markDataAsCorrupted()
+                    pass
 
-
-                trialList.append(aTrial)
+            trialList.append(aTrial)
 
         elif software == "anymaze":
             logging.info("Reading anymaze")
